@@ -9,6 +9,7 @@ from django.http import JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse
 from django.utils.timezone import now
+from django.views.generic import ListView
 
 from network.base.decorators import ajax_required
 from network.base.forms import AntennaInlineFormSet, FrequencyRangeInlineFormSet, StationForm, \
@@ -27,36 +28,79 @@ def station_all_view(request):
     return JsonResponse(data, safe=False)
 
 
-def stations_list(request):
-    """View to render Stations page."""
-    stations = Station.objects.annotate(
-        total_obs=Count('observations'),
-        future_obs=Count('pk', filter=Q(observations__end__gt=now())),
-    ).prefetch_related(
-        'owner', 'antennas', 'antennas__antenna_type', 'antennas__frequency_ranges'
-    ).order_by('-status', 'id')
-    stations_by_status = {'online': 0, 'testing': 0, 'offline': 0, 'future': 0}
-    for station in stations:
-        if station.last_seen is None:
-            stations_by_status['future'] += 1
-        elif station.status == 2:
-            stations_by_status['online'] += 1
-        elif station.status == 1:
-            stations_by_status['testing'] += 1
-        else:
-            stations_by_status['offline'] += 1
+class StationListView(ListView):  # pylint: disable=R0901
+    """Displays a list of stations with pagination"""
+    model = Station
+    context_object_name = "stations"
+    paginate_by = settings.ITEMS_PER_PAGE
+    template_name = "base/stations.html"
+    flag_filters = ['online', 'testing', 'offline', 'future']
+    freq_filters = ['freq']
+    is_filtered = False
+    freq_filter_errors = []
 
-    return render(
-        request, 'base/stations.html', {
-            'stations': stations,
-            'online': stations_by_status['online'],
-            'testing': stations_by_status['testing'],
-            'offline': stations_by_status['offline'],
-            'future': stations_by_status['future'],
-            'mapbox_id': settings.MAPBOX_MAP_ID,
-            'mapbox_token': settings.MAPBOX_TOKEN
-        }
-    )
+    def get_filter_params(self):
+        """
+        Get the parsed filter parameters from the HTTP GET parameters
+        """
+
+        filter_params = {}
+        for param_name in self.flag_filters:
+            param_val = self.request.GET.get(param_name, 1)
+            if param_val != '0':
+                filter_params[param_name] = True
+            else:
+                filter_params[param_name] = False
+                self.is_filtered = True
+        self.freq_filter_errors = []
+        filter_freq = self.request.GET.get('freq', None)
+        if filter_freq:
+            self.is_filtered = True
+            try:
+                filter_freq = int(filter_freq)
+            except ValueError:
+                self.freq_filter_errors.append("Frequency: Invalid value")
+                return filter_params
+            if filter_freq < 0:
+                self.freq_filter_errors.append('Frequency: Value cannot be less than 0')
+            filter_params['freq'] = filter_freq
+        return filter_params
+
+    def get_queryset(self):
+        stations = Station.objects.annotate(
+            total_obs=Count('observations'),
+            future_obs=Count('pk', filter=Q(observations__end__gt=now())),
+        ).select_related('owner').prefetch_related(
+            'antennas', 'antennas__antenna_type', 'antennas__frequency_ranges'
+        ).order_by('-status', 'id')
+
+        filter_params = self.get_filter_params()
+
+        if not filter_params["online"]:
+            stations = stations.exclude(status=2)
+        if not filter_params["testing"]:
+            stations = stations.exclude(status=1)
+        if not filter_params["offline"]:
+            stations = stations.exclude(Q(status=0) & Q(last_seen__isnull=False))
+        if not filter_params["future"]:
+            stations = stations.exclude(last_seen__isnull=True)
+
+        freq = filter_params.get("freq", None)
+        if freq:
+            freq_filter = Q(antennas__frequency_ranges__min_frequency__lte=freq)
+            freq_filter &= Q(antennas__frequency_ranges__max_frequency__gte=freq)
+            stations = stations.filter(freq_filter)
+        return stations
+
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context["is_filtered"] = self.is_filtered
+        context.update(self.get_filter_params())
+        context["mapbox_id"] = settings.MAPBOX_MAP_ID
+        context["mapbox_token"] = settings.MAPBOX_TOKEN
+        context["freq_filter_errors"] = self.freq_filter_errors
+
+        return context
 
 
 def station_view(request, station_id):
@@ -70,30 +114,26 @@ def station_view(request, station_id):
         ),
         id=station_id
     )
+    station_log = StationStatusLog.objects.filter(station=station)
 
     can_schedule = schedule_station_perms(request.user, station)
     can_modify_delete_station = modify_delete_station_perms(request.user, station)
 
     # Calculate uptime
-    uptime = '-'
-    try:
-        latest = StationStatusLog.objects.filter(station=station)[0]
-    except IndexError:
-        latest = None
-    if latest:
-        if latest.status:
-            try:
-                offline = StationStatusLog.objects.filter(station=station, status=0)[0]
-                uptime = latest.changed - offline.changed
-            except IndexError:
-                uptime = now() - latest.changed
-            uptime = str(uptime).split('.')[0]
+    uptime_since = None
+    if station_log:
+        latest_entry = station_log[0]
+        if latest_entry.status > 0:
+            for entry in station_log:
+                if entry.status == 0:
+                    break
+                uptime_since = entry.changed
 
     if request.user.is_authenticated:
         if request.user == station.owner:
             wiki_help = (
-                '<a href="{0}" target="_blank" class="wiki-help"><span class="glyphicon '
-                'glyphicon-question-sign" aria-hidden="true"></span>'
+                '<a href="{0}" target="_blank" class="wiki-help"><span class="bi '
+                'bi-question-circle" aria-hidden="true"></span>'
                 '</a>'.format(settings.WIKI_STATION_URL)
             )
             if station.is_offline:
@@ -120,19 +160,7 @@ def station_view(request, station_id):
             'mapbox_token': settings.MAPBOX_TOKEN,
             'can_schedule': can_schedule,
             'can_modify_delete_station': can_modify_delete_station,
-            'uptime': uptime
-        }
-    )
-
-
-def station_log_view(request, station_id):
-    """View for single station status log."""
-    station = get_object_or_404(Station, id=station_id)
-    station_log = StationStatusLog.objects.filter(station=station)
-
-    return render(
-        request, 'base/station_log.html', {
-            'station': station,
+            'uptime_since': uptime_since,
             'station_log': station_log
         }
     )
@@ -192,12 +220,7 @@ def station_register(request, step=None, station_id=None):
         return redirect(reverse('base:home'))
     if step == '1':
         stations = Station.objects.filter(owner=request.user)
-        return render(
-            request, 'base/station_register_step1.html', {
-                'client_hash': client_hash,
-                'stations': stations
-            }
-        )
+        return render(request, 'base/station_register_step1.html', {'stations': stations})
     if step == '2':
         station = None
         if station_id:
