@@ -29,6 +29,14 @@ def update_future_observations_with_new_tle_sets():
     periodic_task()
 
 
+@APP.task
+def update_future_observations_with_new_transmitter_details():
+    """Wrapper task for 'update_future_observations_with_new_transmitter_details' shared task"""
+    from network.base.tasks import (  # isort:skip
+        update_future_observations_with_new_transmitter_details as periodic_task)
+    periodic_task()
+
+
 @APP.task
 def fetch_data():
     """Wrapper task for 'fetch_data' shared task"""
@@ -87,6 +95,12 @@ def setup_periodic_tasks(sender, **kwargs):  # pylint: disable=W0613
         name='update_future_observations_with_new_tle_sets'
     )
 
+    sender.add_periodic_task(
+        RUN_TWICE_HOURLY,
+        update_future_observations_with_new_transmitter_details.s(),
+        name='update_future_observations_with_new_transmitter_details'
+    )
+
     sender.add_periodic_task(RUN_HOURLY, fetch_data.s(), name='fetch_data')
 
     sender.add_periodic_task(RUN_HOURLY, station_status_update.s(), name='station_status_update')
