@@ -1,10 +1,8 @@
 """Base Django URL mapping for SatNOGS Network"""
 from allauth import urls as allauth_urls
-from avatar import urls as avatar_urls
 from django.conf import settings
-from django.conf.urls import include
 from django.contrib import admin
-from django.urls import path, re_path
+from django.urls import include, path, re_path
 from django.views.static import serve
 
 from network.api.urls import API_URLPATTERNS
@@ -17,7 +15,6 @@ urlpatterns = [
     path('admin/', admin.site.urls),
     path('users/', include(USERS_URLPATTERNS)),
     path('accounts/', include(allauth_urls)),
-    path('avatar/', include(avatar_urls)),
     path('api/', include(API_URLPATTERNS))
 ]
 
